@@ -7,20 +7,20 @@ from __future__ import annotations
 from abc import ABCMeta, abstractmethod
 from datetime import datetime
 from threading import Lock
-from typing import TYPE_CHECKING, Any, List, Tuple
+from typing import TYPE_CHECKING, Any
 
 from mss.exception import ScreenShotError
 from mss.screenshot import ScreenShot
 from mss.tools import to_png
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: nocover
     from collections.abc import Callable, Iterator
 
     from mss.models import Monitor, Monitors
 
 try:
     from datetime import UTC
-except ImportError:
+except ImportError:  # pragma: nocover
     # Python < 3.11
     from datetime import timezone
 
@@ -28,6 +28,8 @@ except ImportError:
 
 lock = Lock()
 
+OPAQUE = 255
+
 
 class MSSBase(metaclass=ABCMeta):
     """This class will be overloaded by a system specific one."""
@@ -39,9 +41,11 @@ class MSSBase(metaclass=ABCMeta):
         /,
         *,
         compression_level: int = 6,
-        display: bytes | str | None = None,  # noqa:ARG002 Linux only
-        max_displays: int = 32,  # noqa:ARG002 Mac only
         with_cursor: bool = False,
+        # Linux only
+        display: bytes | str | None = None,  # noqa: ARG002
+        # Mac only
+        max_displays: int = 32,  # noqa: ARG002
     ) -> None:
         self.cls_image: type[ScreenShot] = ScreenShot
         self.compression_level = compression_level
@@ -75,7 +79,7 @@ class MSSBase(metaclass=ABCMeta):
     def close(self) -> None:  # noqa:B027
         """Clean-up."""
 
-    def grab(self, monitor: Monitor | Tuple[int, int, int, int], /) -> ScreenShot:
+    def grab(self, monitor: Monitor | tuple[int, int, int, int], /) -> ScreenShot:
         """Retrieve screen pixels for a given monitor.
 
         Note: *monitor* can be a tuple like the one PIL.Image.grab() accepts.
@@ -132,28 +136,28 @@ class MSSBase(metaclass=ABCMeta):
         output: str = "monitor-{mon}.png",
         callback: Callable[[str], None] | None = None,
     ) -> Iterator[str]:
-        """Grab a screen shot and save it to a file.
+        """Grab a screenshot and save it to a file.
 
-        :param int mon: The monitor to screen shot (default=0).
-                        -1: grab one screen shot of all monitors
-                         0: grab one screen shot by monitor
-                        N: grab the screen shot of the monitor N
+        :param int mon: The monitor to screenshot (default=0).
+                        -1: grab one screenshot of all monitors
+                         0: grab one screenshot by monitor
+                        N: grab the screenshot of the monitor N
 
         :param str output: The output filename.
 
             It can take several keywords to customize the filename:
             - `{mon}`: the monitor number
-            - `{top}`: the screen shot y-coordinate of the upper-left corner
-            - `{left}`: the screen shot x-coordinate of the upper-left corner
-            - `{width}`: the screen shot's width
-            - `{height}`: the screen shot's height
+            - `{top}`: the screenshot y-coordinate of the upper-left corner
+            - `{left}`: the screenshot x-coordinate of the upper-left corner
+            - `{width}`: the screenshot's width
+            - `{height}`: the screenshot's height
             - `{date}`: the current date using the default formatter
 
             As it is using the `format()` function, you can specify
             formatting options like `{date:%Y-%m-%s}`.
 
         :param callable callback: Callback called before saving the
-            screen shot to a file.  Take the `output` argument as parameter.
+            screenshot to a file.  Take the `output` argument as parameter.
 
         :return generator: Created file(s).
         """
@@ -163,7 +167,7 @@ class MSSBase(metaclass=ABCMeta):
             raise ScreenShotError(msg)
 
         if mon == 0:
-            # One screen shot by monitor
+            # One screenshot by monitor
             for idx, monitor in enumerate(monitors[1:], 1):
                 fname = output.format(mon=idx, date=datetime.now(UTC) if "{date" in output else None, **monitor)
                 if callable(callback):
@@ -172,8 +176,8 @@ class MSSBase(metaclass=ABCMeta):
                 to_png(sct.rgb, sct.size, level=self.compression_level, output=fname)
                 yield fname
         else:
-            # A screen shot of all monitors together or
-            # a screen shot of the monitor N.
+            # A screenshot of all monitors together or
+            # a screenshot of the monitor N.
             mon = 0 if mon == -1 else mon
             try:
                 monitor = monitors[mon]
@@ -189,7 +193,7 @@ class MSSBase(metaclass=ABCMeta):
             yield output
 
     def shot(self, /, **kwargs: Any) -> str:
-        """Helper to save the screen shot of the 1st monitor, by default.
+        """Helper to save the screenshot of the 1st monitor, by default.
         You can pass the same arguments as for ``save``.
         """
         kwargs["mon"] = kwargs.get("mon", 1)
@@ -198,7 +202,6 @@ class MSSBase(metaclass=ABCMeta):
     @staticmethod
     def _merge(screenshot: ScreenShot, cursor: ScreenShot, /) -> ScreenShot:
         """Create composite image by blending screenshot and mouse cursor."""
-
         (cx, cy), (cw, ch) = cursor.pos, cursor.size
         (x, y), (w, h) = screenshot.pos, screenshot.size
 
@@ -232,7 +235,7 @@ class MSSBase(metaclass=ABCMeta):
                 if not alpha:
                     continue
 
-                if alpha == 255:
+                if alpha == OPAQUE:
                     screen_raw[spos : spos + 3] = cursor_raw[cpos : cpos + 3]
                 else:
                     alpha2 = alpha / 255
@@ -245,7 +248,7 @@ class MSSBase(metaclass=ABCMeta):
     def _cfactory(
         attr: Any,
         func: str,
-        argtypes: List[Any],
+        argtypes: list[Any],
         restype: Any,
         /,
         errcheck: Callable | None = None,
