@@ -28,12 +28,12 @@ from ctypes import (
 )
 from ctypes.util import find_library
 from threading import current_thread, local
-from typing import TYPE_CHECKING, Any, Tuple
+from typing import TYPE_CHECKING, Any
 
 from mss.base import MSSBase, lock
 from mss.exception import ScreenShotError
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: nocover
     from mss.models import CFunctions, Monitor
     from mss.screenshot import ScreenShot
 
@@ -42,6 +42,10 @@ __all__ = ("MSS",)
 
 PLAINMASK = 0x00FFFFFF
 ZPIXMAP = 2
+BITS_PER_PIXELS_32 = 32
+SUPPORTED_BITS_PER_PIXELS = {
+    BITS_PER_PIXELS_32,
+}
 
 
 class Display(Structure):
@@ -103,11 +107,11 @@ class XImage(Structure):
         ("bitmap_bit_order", c_int),  # LSBFirst, MSBFirst
         ("bitmap_pad", c_int),  # 8, 16, 32 either XY or ZPixmap
         ("depth", c_int),  # depth of image
-        ("bytes_per_line", c_int),  # accelarator to next line
+        ("bytes_per_line", c_int),  # accelerator to next line
         ("bits_per_pixel", c_int),  # bits per pixel (ZPixmap)
-        ("red_mask", c_ulong),  # bits in z arrangment
-        ("green_mask", c_ulong),  # bits in z arrangment
-        ("blue_mask", c_ulong),  # bits in z arrangment
+        ("red_mask", c_ulong),  # bits in z arrangement
+        ("green_mask", c_ulong),  # bits in z arrangement
+        ("blue_mask", c_ulong),  # bits in z arrangement
     )
 
 
@@ -215,7 +219,7 @@ def _error_handler(display: Display, event: XErrorEvent) -> int:
     return 0
 
 
-def _validate(retval: int, func: Any, args: Tuple[Any, Any], /) -> Tuple[Any, Any]:
+def _validate(retval: int, func: Any, args: tuple[Any, Any], /) -> tuple[Any, Any]:
     """Validate the returned value of a C function call."""
     thread = current_thread()
     if retval != 0 and thread not in _ERROR:
@@ -233,7 +237,7 @@ def _validate(retval: int, func: Any, args: Tuple[Any, Any], /) -> Tuple[Any, An
 #
 # Note: keep it sorted by cfunction.
 CFUNCTIONS: CFunctions = {
-    # cfunction: (attr, argtypes, restype)
+    # Syntax: cfunction: (attr, argtypes, restype)
     "XCloseDisplay": ("xlib", [POINTER(Display)], c_void_p),
     "XDefaultRootWindow": ("xlib", [POINTER(Display)], POINTER(XWindowAttributes)),
     "XDestroyImage": ("xlib", [POINTER(XImage)], c_void_p),
@@ -325,6 +329,14 @@ class MSS(MSSBase):
         self._handles.drawable = cast(self._handles.root, POINTER(Display))
 
     def close(self) -> None:
+        # Clean-up
+        if self._handles.display:
+            with lock:
+                self.xlib.XCloseDisplay(self._handles.display)
+            self._handles.display = None
+            self._handles.drawable = None
+            self._handles.root = None
+
         # Remove our error handler
         if self._handles.original_error_handler:
             # It's required when exiting MSS to prevent letting `_error_handler()` as default handler.
@@ -335,24 +347,17 @@ class MSS(MSSBase):
             self.xlib.XSetErrorHandler(self._handles.original_error_handler)
             self._handles.original_error_handler = None
 
-        # Clean-up
-        if self._handles.display:
-            self.xlib.XCloseDisplay(self._handles.display)
-            self._handles.display = None
-            self._handles.drawable = None
-            self._handles.root = None
-
         # Also empty the error dict
         _ERROR.clear()
 
     def _is_extension_enabled(self, name: str, /) -> bool:
         """Return True if the given *extension* is enabled on the server."""
-        with lock:
-            major_opcode_return = c_int()
-            first_event_return = c_int()
-            first_error_return = c_int()
+        major_opcode_return = c_int()
+        first_event_return = c_int()
+        first_error_return = c_int()
 
-            try:
+        try:
+            with lock:
                 self.xlib.XQueryExtension(
                     self._handles.display,
                     name.encode("latin1"),
@@ -360,9 +365,9 @@ class MSS(MSSBase):
                     byref(first_event_return),
                     byref(first_error_return),
                 )
-            except ScreenShotError:
-                return False
-            return True
+        except ScreenShotError:
+            return False
+        return True
 
     def _set_cfunctions(self) -> None:
         """Set all ctypes functions and attach them to attributes."""
@@ -433,7 +438,7 @@ class MSS(MSSBase):
 
         try:
             bits_per_pixel = ximage.contents.bits_per_pixel
-            if bits_per_pixel != 32:
+            if bits_per_pixel not in SUPPORTED_BITS_PER_PIXELS:
                 msg = f"[XImage] bits per pixel value not (yet?) implemented: {bits_per_pixel}."
                 raise ScreenShotError(msg)
 
