@@ -2,15 +2,15 @@
 Source: https://github.com/BoboTiG/python-mss.
 """
 
-from typing import Any, Dict, List, NamedTuple, Tuple
+from typing import Any, NamedTuple
 
-Monitor = Dict[str, int]
-Monitors = List[Monitor]
+Monitor = dict[str, int]
+Monitors = list[Monitor]
 
-Pixel = Tuple[int, int, int]
-Pixels = List[Tuple[Pixel, ...]]
+Pixel = tuple[int, int, int]
+Pixels = list[tuple[Pixel, ...]]
 
-CFunctions = Dict[str, Tuple[str, List[Any], Any]]
+CFunctions = dict[str, tuple[str, list[Any], Any]]
 
 
 class Pos(NamedTuple):
